# Create Data Field
## Name
AngleLeftField
## Description
Angle rotation of the left leg from vertical
## Data Type
Integer
## Position
2
## Min Cardinality
1
## Max Cardinality
1
## In Data Structure

## Data Class
## Glossary Term
## Namespace
> forms part of qualified name
## Version

## In Data Dictionary

___

# Create Data Field
## Name
PatientId
## Description
Unique identifier of the patient
## Data Type
String
## Position
0
## Min Cardinality
1
## Max Cardinality
1
## In Data Structure


## Data Class 
## Glossary Term
Patient Identifier

## Namespace
> forms part of qualified name

## Version

## In Data Dictionary
Clinical Trial Data Dictionary
## Qualified Name
DataField::PatientId